@@ -382,7 +382,7 @@ test_that("translate sql server -> spark INSERT INTO SELECT", {
   )
   expect_equal_ignore_spaces(
     sql,
-    "WITH insertion_temp AS (\n(SELECT c FROM cte1) UNION ALL (SELECT b int FROM a ))\nINSERT OVERWRITE TABLE a  SELECT * FROM insertion_temp;"
+    "WITH insertion_temp AS (\n(SELECT c FROM cte1) UNION ALL (SELECT b int FROM a ))\nINSERT OVERWRITE TABLE a (b int) SELECT * FROM insertion_temp;"
   )
 })
 
@@ -392,7 +392,7 @@ test_that("translate sql server -> spark INSERT INTO VALUES", {
   )
   expect_equal_ignore_spaces(
     sql,
-    "WITH insertion_temp AS (\n(SELECT * FROM VALUES (1,0),(2,0),(3,1) T(key,value)) UNION ALL (SELECT key,value FROM my_table ))\nINSERT OVERWRITE TABLE my_table  SELECT * FROM insertion_temp;"
+    "WITH insertion_temp AS (\n(SELECT * FROM VALUES (1,0),(2,0),(3,1) T(key,value)) UNION ALL (SELECT key,value FROM my_table ))\nINSERT OVERWRITE TABLE my_table (key,value) SELECT * FROM insertion_temp;"
   )
 })
 
